<?php

/**
 * @package     Sprinix_MultiTax
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\MultiTax\Block\Adminhtml\Form\Field;
use Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray;
use Magento\Framework\DataObject;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\View\Element\BlockInterface;

/**
 * Class Additional
 * @package Sprinix\MultiTax\Block\Adminhtml\Form\Field
 */
class Additional extends AbstractFieldArray
{
    /**
     * @var Tax column
     */
    private $taxRenderer;

    /**
     * add config columns
     */
    protected function _prepareToRender()
    {
        $this->addColumn('label', ['label' => __('Tax Name'), 'class' => 'required-entry']);
        $this->addColumn('price', ['label' => __('Price'), 'class' => 'required-entry']);
        $this->addColumn('handling_type', [
            'label' => __('Price Type'),
            'renderer' => $this->getTaxRenderer()
        ]);
        $this->_addAfter = false;
        $this->_addButtonLabel = __('Add Tax Row');
    }

    /**
     * @param DataObject $row
     */
    protected function _prepareArrayRow(DataObject $row): void
    {
        $options = [];
        $tax = $row->getTax();
        if ($tax !== null) {
            $options['option_' . $this->getTaxRenderer()->calcOptionHash($tax)] = 'selected="selected"';
        }
        $row->setData('option_extra_attrs', $options);
    }

    /**
     * @return BlockInterface|Tax
     * @throws LocalizedException
     */
    private function getTaxRenderer()
    {
        if (!$this->taxRenderer) {
            $this->taxRenderer = $this->getLayout()->createBlock(
                TaxColumn::class,
                '',
                ['data' => ['is_render_to_js_template' => true]]
            );
        }
        return $this->taxRenderer;
    }
}
