<?php

/**
 * @package     Sprinix_MultiTax
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\MultiTax\Helper;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Framework\Serialize\Serializer\Json;
use Magento\Store\Model\ScopeInterface;

/**
 * Class Data
 * @package Sprinix\MultiTax\Helper
 */
class Data extends AbstractHelper
{
    /**
     * enable module
     */
    const CONFIG_CUSTOM_IS_ENABLED = 'subcharge/general/active';

    /**
     * Custom fee config path
     */
    const CONFIG_CUSTOM_FEE = 'subcharge/general/price';

    /**
     * fee type
     */
    const CONFIG_FEE_TYPE = 'subcharge/general/handling_type';

    /**
     * ranges
     */
    const CONFIG_RANGES_FEE_TYPE = 'subcharge/general/ranges';

    /**
     * @var Json
     */
    private $serialize;

    /**
     * Data constructor.
     * @param Context $context
     * @param Json $serialize
     */
    public function __construct(
        Context $context,
        Json $serialize
    )
    {
        $this->serialize = $serialize;
        parent::__construct($context);
    }

    /**
     * @return mixed
     */
    public function isModuleEnabled()
    {
        $storeScope = ScopeInterface::SCOPE_STORE;
        return $this->scopeConfig->getValue(self::CONFIG_CUSTOM_IS_ENABLED, $storeScope);
    }

    /**
     * @return mixed
     */
    public function getExtrafee()
    {
        $storeScope = ScopeInterface::SCOPE_STORE;
        return $this->scopeConfig->getValue(self::CONFIG_CUSTOM_FEE, $storeScope);
    }

    /**
     * @return mixed
     */
    public function getFeeType()
    {
        $storeScope = ScopeInterface::SCOPE_STORE;
        return $this->scopeConfig->getValue(self::CONFIG_FEE_TYPE, $storeScope);
    }

    /**
     * @return array
     */
    public function getFeeRanges()
    {
        $storeScope = ScopeInterface::SCOPE_STORE;
        $FeeRange = $this->scopeConfig->getValue(self::CONFIG_RANGES_FEE_TYPE, $storeScope);
        $arr=[];
        if ($FeeRange) {
            $unsearl = $this->serialize->unserialize($FeeRange);
            foreach($unsearl as $data) {
                $arr[$data['label']]['label'] = $data['label'];
                $arr[$data['label']]['price'] = $data['price'];
                $arr[$data['label']]['type'] = $data['handling_type'];
            }
        }
        return $arr;
    }
}
