<?php

/**
 * @package     Sprinix_MultiTax
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\MultiTax\Model\Quote\Total;
use Magento\Quote\Model\Quote\Address\Total;
use Magento\Quote\Model\Quote\Address\Total\AbstractTotal;
use Sprinix\MultiTax\Helper\Data;
use Magento\Tax\Model\Calculation;
use Magento\Quote\Model\Quote;
use Magento\Quote\Api\Data\ShippingAssignmentInterface;
use Psr\Log\LoggerInterface;

class Fee extends AbstractTotal
{
    /**
     * @var Data
     */
    protected $helperData;

    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * @var Calculation
     */
    private $taxCalculator;

    /**
     * Collect grand total address amount
     *
     * @param \Magento\Quote\Model\Quote $quote
     * @param \Magento\Quote\Api\Data\ShippingAssignmentInterface $shippingAssignment
     * @param \Magento\Quote\Model\Quote\Address\Total $total
     * @return $this
     */
    protected $quoteValidator = null;

    /**
     * Fee constructor.
     * @param Data $helperData
     * @param Calculation $taxCalculator
     * @param LoggerInterface $logger
     */
    public function __construct(
        Data $helperData,
        Calculation $taxCalculator,
        LoggerInterface $logger
    ) {
        $this->helperData = $helperData;
        $this->logger = $logger;
        $this->taxCalculator = $taxCalculator;
    }

    /**
     * @param Quote $quote
     * @param ShippingAssignmentInterface $shippingAssignment
     * @param Total $total
     * @return $this|AbstractTotal
     */
    public function collect(
        Quote $quote,
        ShippingAssignmentInterface $shippingAssignment,
       Total $total
    ) {
        parent::collect($quote, $shippingAssignment, $total);
        if (!count($shippingAssignment->getItems())) {
            return $this;
        }
        $ranges = $this->helperData->getFeeRanges();
        $enabled = $this->helperData->isModuleEnabled();
        $subtotal = $total->getTotalAmount('subtotal');
        $fee = 0;
        $type = [];
        if ($enabled) {
            foreach($ranges as $key => $value) {
                $type[$value['label']]['type'] = $value['type'];
                $type[$value['label']]['label'] = $value['label'];
                if ($value['type'] == 'P') {
                    $fee += ($subtotal * $value['price'] / 100);
                    $type[$value['label']]['price'] =  ($subtotal * $value['price'] / 100);
                } elseif ($value['type'] == 'F') {
                    $type[$value['label']]['price'] =  $value['price'];
                    $fee += $value['price'];
                }
            }
            $total->setTotalAmount('fee', $fee);
            $total->setBaseTotalAmount('fee', $fee);
            $total->setPaymentFee(json_encode($type));
            $quote->setPaymentFee(json_encode($type));
            $this->_calculateTax($total);
        }
        return $this;
    }

    /**
     * @param Quote $quote
     * @param Total $total
     * @return array
     */
    public function fetch(
        Quote $quote,
        Total $total
    ) {
        $result = [];
        try {
            $enabled = $this->helperData->isModuleEnabled();
            $fee = json_decode($quote->getPaymentFee(),true);
            if ($enabled) {
                $result = [
                    'code' => 'fee',
                    'value' => $fee
                ];
            }
        } catch (\Exception $e) {
            $this->logger->info($e->getMessage());
        }
        return $result;
    }

    /**
     * @param Total $total
     * @return $this
     */
    protected function _calculateTax(Total $total)
    {
        $total->setFeeTax();
        return $this;
    }
}
