<?php

/**
 * @package     Sprinix_MultiTax
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\MultiTax\Observer;
use Magento\Framework\Event\Observer as EventObserver;
use Magento\Framework\Event\ObserverInterface;
use Magento\Quote\Model\QuoteRepository;
use Psr\Log\LoggerInterface;

/**
 * Class Order
 * @package Sprinix\MultiTax\Observer
 */
class Order implements ObserverInterface
{
    /**
     * @var QuoteRepository
     */
    protected $quoteRepository;

    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * Order constructor.
     * @param QuoteRepository $quoteRepository
     * @param LoggerInterface $logger
     */
    public function __construct(
        QuoteRepository $quoteRepository,
        LoggerInterface $logger
    ) {
        $this->quoteRepository = $quoteRepository;
        $this->logger = $logger;
    }

    /**
     * @param EventObserver $observer
     * @return $this|void
     */
    public function execute(EventObserver $observer)
    {

        try {
            $order = $observer->getOrder();
            $quoteId = $order->getQuoteId();
            /** @var \Magento\Quote\Model\Quote $quote */
            $quote = $this->quoteRepository->get($quoteId);
            $order->setPaymentFee($quote->getPaymentFee());
            return $this;
        } catch (\Exception $e) {
            $this->logger->info($e->getMessage());
        }
        return;
    }
}
